@@ -16,6 +16,7 @@
 
 #include <Plasma/Plasma>
 
+#include "action.h"
 #include "applet.h"
 #include "appletpopup.h"
 #include "containment.h"
@@ -79,6 +80,13 @@ struct AppletForeign {
     QML_FOREIGN(Plasma::Applet)
 };
 
+struct ActionForeign {
+    Q_GADGET
+    QML_NAMED_ELEMENT(Action)
+    QML_FOREIGN(QAction)
+    QML_EXTENDED(ActionExtension)
+};
+
 class CoreBindingsPlugin : public QQmlExtensionPlugin
 {
     Q_OBJECT
