@@ -114,7 +114,9 @@ void Applet::save(KConfigGroup &g) const
     // we call the dptr member directly for locked since isImmutable()
     // also checks kiosk and parent containers
     group.writeEntry("immutability", (int)d->immutability);
-    group.writeEntry("plugin", d->appletDescription.pluginId());
+    // Use pluginName as might be different from d->appletDescription.pluginId()
+    // In case X-Plasma-RootPath is used
+    group.writeEntry("plugin", pluginName());
 
     if (!d->started) {
         return;
@@ -251,12 +253,13 @@ KConfigLoader *Applet::configScheme() const
     if (!d->configLoader) {
         QString xmlPath;
 
-        if (d->package.isValid()) {
-            xmlPath = d->package.filePath("mainconfigxml");
-        } else {
-            if (QFile::exists(qrcPath() + QLatin1String("main.xml"))) {
-                xmlPath = qrcPath() + QLatin1String("main.xml");
+        if (QFile::exists(qrcPath())) {
+            const QString path = qrcPath() + QLatin1String("main.xml");
+            if (QFile::exists(path)) {
+                xmlPath = path;
             }
+        } else if (d->package.isValid()) {
+            xmlPath = d->package.filePath("mainconfigxml");
         }
 
         KConfigGroup cfg = config();
@@ -846,13 +849,17 @@ void Applet::configChanged()
     }
 }
 
-QUrl Applet::fileUrl(const QByteArray &key, const QString &filename) const
+QUrl Applet::fileUrl(const QString &filename) const
 {
-    if (d->package.isValid()) {
-        return d->package.fileUrl(key, filename);
-    } else {
+    if (QFile::exists(qrcPath())) {
         return QUrl(QLatin1String("qrc") + qrcPath() + filename);
     }
+
+    if (d->package.isValid()) {
+        return d->package.fileUrl("ui", filename);
+    }
+
+    return QUrl();
 }
 
 QUrl Applet::mainScript() const
@@ -871,13 +878,13 @@ QUrl Applet::mainScript() const
 
 QUrl Applet::configModel() const
 {
-    if (d->package.isValid()) {
-        return d->package.fileUrl("configmodel");
-    } else {
+    if (QFile::exists(qrcPath())) {
         const QString path = qrcPath() + QLatin1String("config.qml");
         if (QFile::exists(path)) {
             return QUrl(QLatin1String("qrc") + path);
         }
+    } else if (d->package.isValid()) {
+        return d->package.fileUrl("configmodel");
     }
 
     return QUrl();
@@ -942,7 +949,11 @@ QString Applet::translationDomain() const
 
 QString Applet::qrcPath() const
 {
-    return QLatin1String(":/qt/qml/plasma/applet/") + pluginName().replace(QLatin1Char('.'), QLatin1Char('/')) + QLatin1String("/");
+    QString rootPath = d->appletDescription.value(u"X-Plasma-RootPath");
+    if (rootPath.isEmpty()) {
+        rootPath = d->appletDescription.pluginId();
+    }
+    return QLatin1String(":/qt/qml/plasma/applet/") + rootPath.replace(QLatin1Char('.'), QLatin1Char('/')) + QLatin1String("/");
 }
 
 } // Plasma namespace
