@@ -356,8 +356,6 @@ void AppletPrivate::contextualActions_append(QQmlListProperty<QAction> *prop, QA
     a->d->contextualActions.append(action);
     if (action) { // some operations like inserting in the middle may append nullptr
         QObject::connect(action, &QObject::destroyed, a, [a, action]() {
-            if (a->destroyed())
-                return;
             a->d->contextualActions.removeAll(action);
             Q_EMIT a->contextualActionsChanged(a->d->contextualActions);
         });
