@@ -6,24 +6,12 @@
 */
 
 #include "configmodel.h"
-#include "Plasma/Applet"
-#include "Plasma/Containment"
+
+#include "applet.h"
 #include "configcategory_p.h"
-#include "configview.h"
-#include "debug_p.h"
-#include "sharedqmlengine.h"
 
 #include <QDebug>
-#include <QDir>
-#include <QQmlComponent>
-#include <QQmlContext>
-#include <QQmlEngine>
-#include <QQuickItem>
-
-#include <KLocalizedString>
-
-#include <Plasma/Corona>
-#include <Plasma/PluginLoader>
+#include <QPointer>
 
 namespace PlasmaQuick
 {
@@ -217,7 +205,7 @@ QVariant ConfigModel::data(const QModelIndex &index, int role) const
         const QString source = d->categories.at(index.row())->source();
         // Quick check if source is an absolute path or not
         if (d->appletInterface && !source.isEmpty() && !(source.startsWith(QLatin1Char('/')) && source.endsWith(QLatin1String("qml")))) {
-            return d->appletInterface.data()->fileUrl("ui", source);
+            return d->appletInterface.data()->fileUrl(source);
         } else {
             return source;
         }
